bayespy.inference.vmp.nodes.gaussian.GaussianGammaISODistribution.compute_phi_from_parents
==========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISODistribution.compute_phi_from_parents